<?php

require_once( 'class.focussitecall-model.php' );
require_once( 'class.focussitecall-sitecalls-model.php' );
require_once( 'class.focussitecall-fcc-provider.php' );
require_once( 'class.focussitecall-notices.php' );

class FocusSitecall_Admin_Post_Controller {
	public function register_actions() {
		add_action( 'admin_post_assign_sitecalls', array( $this, 'assign_sitecalls' ) );
		add_action( 'admin_post_refresh_sitecalls', array( $this, 'get_sitecalls' ) );
		add_action( 'admin_post_update_credentials', array( $this, 'update_credentials' ) );
	}

	public function assign_sitecalls() {
	    if ( isset( $_POST['default_global_sitecall_button'] ) ) {
			update_option( FocusSitecall_Model::SITECALL_DEFAULT_GLOBAL_OPTION_KEY, sanitize_text_field( $_POST['default_global_sitecall']) );
			$success = true;
			$message = __('SiteCall`s assigment to themes was updated.', 'focus-sitecall-pro');
		} elseif ( isset( $_POST['assignTo'] ) && current( $_POST['assignTo'] ) !== "-1" ) {
	        $assignTo = sanitize_text_field( current( $_POST['assignTo'] ) );

			if ( ! empty( $_POST['bulk-assign'] ) && is_array( $_POST['bulk-assign'] ) && isset( $assignTo ) ) {
                $_POST['bulk-assign'] = array_map( 'sanitize_text_field', $_POST['bulk-assign'] );
			    $templates_sitecall_list = FocusSitecall_Templates_Sitecalls_Model::getAll();

				foreach ( $_POST['bulk-assign'] as $template ) {
					if ( $assignTo === '0' ) {
						unset( $templates_sitecall_list[ $template ] );
					} else {
						$templates_sitecall_list[ $template ] = $assignTo;
					}
				}
				FocusSitecall_Templates_Sitecalls_Model::setAll( $templates_sitecall_list );

				$success = true;
				$message = __('Assigned to templates.', 'focus-sitecall-pro');
			} else {
				$success = false;
				$message = __('Not assigned to templates.', 'focus-sitecall-pro');
			}
		}

		$this->redirect( esc_url( $_POST['_wp_http_referer'] ), $success, $message );
	}


	public function get_sitecalls() {
		$provider    = new FocusSitecall_Fcc_Provider();
		$credentials = get_option( 'sitecall_credentials_option' );
		$domain      = $credentials['domain'];
		$api_key     = $credentials['api_key'];

		if ( $credentials ) {
			$discoverDomainResult = $provider->discoverDomain( $domain );

			if ( isset( $discoverDomainResult['success'] ) && $discoverDomainResult['success'] && isset( $discoverDomainResult['data']['domain'] ) ) {
				$getSitecallsResult = $provider->getSitecalls( $discoverDomainResult['data']['domain'], $api_key );

				if ( isset( $getSitecallsResult['success'] ) && $getSitecallsResult['success'] && isset( $getSitecallsResult['data'] ) ) {
					$siteCallsToSave = array_map( function ( $sitecall ) {
						return [
							'id'     => $sitecall['id'],
							'paste'  => $sitecall['code'],
							'name'   => $sitecall['name'],
							'active' => $sitecall['active'],
						];

					}, $getSitecallsResult['data'] );
					FocusSitecall_Sitecalls_Model::setAll( $siteCallsToSave );
					$success = true;
					$message = __('Successfully refreshed list of SiteCall widgets.', 'focus-sitecall-pro');

				} else {
					$success = false;
					$message = __('Invalid FCC domain or token.', 'focus-sitecall-pro');
				}
			} else {
				$success = false;
				$message = __('Invalid FCC domain or token.', 'focus-sitecall-pro');
			}
		} else {
			$success = false;
			$message = __('Invalid FCC domain or token.', 'focus-sitecall-pro');
		}

		update_option( 'focussitecall_connected', $success );
		$this->redirect( esc_url( $_POST['_wp_http_referer'] ), $success, $message );
	}

	public function update_credentials() {
	    if ( isset( $_POST['sitecall_credentials_option'] ) ) {
            $_POST['sitecall_credentials_option'] = array_map('sanitize_text_field', $_POST['sitecall_credentials_option']);
			update_option( 'sitecall_credentials_option', $_POST['sitecall_credentials_option'] );;
		}

		$this->get_sitecalls();
	}

	private function redirect( $url, $success, $message ) {
		if ( $success ) {
			$type = FocusSitecall_Notices::NOTICE_SUCCESS;
		} else {
			$type = FocusSitecall_Notices::NOTICE_ERROR;
		}
		FocusSitecall_Notices::setNotice( $type, $message );

		wp_redirect( $url );
	}

}