<?php

class FocusSitecall_Credentials {
	private $options;


	public function create_admin_page() {
		$this->options = get_option( 'sitecall_credentials_option' );


		$connected = (bool)get_option( 'focussitecall_connected' );

		$displayable = $connected ?
            '<span style="font-weight:bold; color:green">' . __('connected', 'focus-sitecall-pro') . '</span>'
            : '<span style="font-weight:bold; color:red">' . __('not connected', 'focus-sitecall-pro') . '</span>';

		?>

        <div class="wrap">
            <h1><?php _e('Focus SiteCall settings', 'focus-sitecall-pro'); ?></h1>

			<?php if ( ! $connected ): ?>
                <p style="font-size:16px;"><?php _e('Thank you for download "Focus SiteCall"', 'focus-sitecall-pro'); ?></p>

                <p style="font-size:16px;"><?php _e('To use "Focus SiteCall" you need to create an account here:', 'focus-sitecall-pro'); ?> <a href="https://focustelecom.pl/sitecall/" target="_blank">[SiteCall]</a>.

                <?php endif; ?>

            <p><?php _e('Connection status:', 'focus-sitecall-pro'); ?> <?php echo $displayable; ?> .</p>
            <form method="post" action="admin-post.php">
				<?php
				settings_fields( 'sitecall_credentials_option_group' );
				echo '<table class="form-table">';

				do_settings_fields( 'sitecall-settings-admin', 'sitecall_credentials_section' );

				echo '</table>';

				?>
                <input type="hidden" name="action" value="update_credentials"/>
				<?php
				submit_button( __('Save changes', 'focus-sitecall-pro') );
				?>
            </form>
        </div>
		<?php
	}

	public function page_init() {
		register_setting(
			'sitecall_credentials_option_group', // Option group
			'sitecall_credentials_option', // Option name
			array( $this, 'sanitize' ) // Sanitize
		);

		add_settings_section(
			'sitecall_credentials_section', // ID
			__('Authorization data', 'focus-sitecall-pro'), // Title
			array( $this, 'print_section_info' ), // Callback
			'sitecall-settings-admin' // Page
		);

		add_settings_field(
			'domain', // ID
			__('FCC domain', 'focus-sitecall-pro'), // Title
			array( $this, 'domain_callback' ), // Callback
			'sitecall-settings-admin', // Page
			'sitecall_credentials_section' // Section
		);

		add_settings_field(
			'api_key',
			__('API key', 'focus-sitecall-pro'),
			array( $this, 'api_key_callback' ),
			'sitecall-settings-admin',
			'sitecall_credentials_section'
		);

	}


	public function sanitize( $input ) {
		$new_input = array();
		if ( isset( $input['domain'] ) ) {
			$new_input['domain'] = sanitize_text_field( $input['domain'] );
		}

		if ( isset( $input['api_key'] ) ) {
			$new_input['api_key'] = sanitize_text_field( $input['api_key'] );
		}

		return $new_input;
	}


	public function print_section_info() {
	}

	public function domain_callback() {
		printf(
			'<input style="width: 300px" type="text" id="domain" name="sitecall_credentials_option[domain]" value="%s" />',
			isset( $this->options['domain'] ) ? esc_attr( $this->options['domain'] ) : ''
		);
	}

	public function api_key_callback() {
		printf(
			'<input style="width: 300px" type="text" id="api_key" name="sitecall_credentials_option[api_key]" value="%s" />',
			isset( $this->options['api_key'] ) ? esc_attr( $this->options['api_key'] ) : ''
		);
        printf('<div title="%s" class="dashicons dashicons-info" style="margin:0; padding:2px 2px 2px 5px;"></div>',
            __('API key can be generated in FCC panel 
in Administration bookmark -> Integrations -> SiteCall.', 'focus-sitecall-pro'));
	}
}