<?php

require_once( 'class.focussitecall-model.php' );

class FocusSitecall_Templates_Sitecalls_Model extends FocusSitecall_Model {
	const SITECALL_TEMPLATES_SITECALLS_OPTION_KEY = 'focussitecall_templetates_sitecalls';
	const DEFAULT_TEMPLATE_KEY = 'default';
	const DEFAULT_TEMPLATE_NAME = "Domyślny Szablon";

	public static function getAll() {
		return self::getAllByKey( self::SITECALL_TEMPLATES_SITECALLS_OPTION_KEY );
	}

	public static function setAll( array $data ) {
		self::setAllByKey( $data, self::SITECALL_TEMPLATES_SITECALLS_OPTION_KEY );
	}

	public static function getPageTemplatesWithDefault() {
		$templates                               = wp_get_theme()->get_page_templates();
		$templates[ self::DEFAULT_TEMPLATE_KEY ] = FocusSitecall_Templates_Sitecalls_Model::DEFAULT_TEMPLATE_NAME;

		return $templates;
	}

	public static function getDefaultTemplateWidget( $postMeta, $postId ) {
		$templateName = self::getTemplateName($postMeta, $postId);
		$widgetId = self::getTemplateWidgetId($templateName);

		return self::getWidgetIfExists( $widgetId );
	}

	public static function assignActiveGlobalWidget( $templateWidget ) {
		$defaultGlobalWidgetId = get_option( FocusSitecall_Model::SITECALL_DEFAULT_GLOBAL_OPTION_KEY );

		if ( ! isset( $templateWidget['id'] ) && $defaultGlobalWidgetId && $defaultGlobalWidgetId !== "0" ) {
			return self::getWidgetIfExists( $defaultGlobalWidgetId );
		}

		return $templateWidget;
	}

	public static function assignActiveTemplateWidget( $globalWidget, $postMeta, $postId ) {
		$defaultTemplateWidget = self::getDefaultTemplateWidget( $postMeta, $postId );

		if ( empty( $globalWidget ) && isset( $defaultTemplateWidget['id'] ) ) {
			return $defaultTemplateWidget;
		}

		return $globalWidget;
	}

	public static function getTemplateName($postMeta, $postId) {
		$post      = get_post( $postId );
		$templates = self::getPageTemplatesWithDefault();

		if ( isset( $postMeta['_wp_page_template'] ) && current( $postMeta['_wp_page_template'] ) === self::DEFAULT_TEMPLATE_KEY || $post->post_modified_gmt === "0000-00-00 00:00:00" ) {
			$templateName = isset( $templates[ self::DEFAULT_TEMPLATE_KEY ] ) ? $templates[ self::DEFAULT_TEMPLATE_KEY ] : '';
		} else {
			$templateName = isset( $templates[ get_page_template_slug( $post->ID ) ] ) ? $templates[ get_page_template_slug( $postId ) ] : '';
		}

		return $templateName;
	}

	public static function getTemplateWidgetId($templateName) {
		$templatesWithWidgets = self::getAll();
		$templates            = self::getPageTemplatesWithDefault();

		$widgetId = '';
		if ( isset( $templatesWithWidgets[ $templateName ] ) ) {
			$widgetId = $templatesWithWidgets[ $templateName ];
		} elseif ( in_array( $templateName, $templates ) ) {
			$widgetId = '0';
		}

		return $widgetId;
	}

	public static function getWidgetIfExists( $widgetId ) {
		global $post;

        if( ! isset($post->ID) ) {
            return [];
        }

		$postMeta = get_post_meta($post->ID);
		$defaultGlobalWidgetId = get_option( FocusSitecall_Model::SITECALL_DEFAULT_GLOBAL_OPTION_KEY );
		$templateName = self::getTemplateName($postMeta, $post->ID);
		$templateWidgetId = self::getTemplateWidgetId($templateName);

		switch ( $widgetId ) {
			case "0":
				if (current($postMeta[FocusSitecall_Add_Widget::SITECALL_WIDGET]) === FocusSitecall_Add_Widget::SITECALL_TEMPLATE_WIDGET
				    && isset($defaultGlobalWidgetId)
				    && $defaultGlobalWidgetId !== FocusSitecall_Sitecalls_Model::NO_WIDGETS_DEFINED
					&& $defaultGlobalWidgetId !== "0") {
					$widget = FocusSitecall_Sitecalls_Model::getWidgetById( $defaultGlobalWidgetId );
				} elseif (current($postMeta[FocusSitecall_Add_Widget::SITECALL_WIDGET]) === FocusSitecall_Add_Widget::SITECALL_GLOBAL_WIDGET
					&& !empty($templateWidgetId)) {
					$widget = FocusSitecall_Sitecalls_Model::getWidgetById( $templateWidgetId );
				} else {
					$widget['name'] = "brak";
				}
				break;
			default:
				$widget = FocusSitecall_Sitecalls_Model::getWidgetById( $widgetId );
		}

		return $widget;
	}
}
