<?php

class FocusSitecall_Add_Widget {
	const SITECALL_WIDGET = 'sitecall_widget';
	const SITECALL_GLOBAL_WIDGET = 'sitecall_global_widget';
	const SITECALL_TEMPLATE_WIDGET = 'sitecall_template_widget';

	public function register_actions() {
		add_action( 'add_meta_boxes', array( $this, 'page_widget_dropdown' ) );
		add_action( 'save_post', array( $this, 'save_post' ) );
	}

	public static function add_to_footer() {
		global $post;
		$postMeta = get_post_meta( $post->ID );
		$widgetId = is_array( $postMeta[ self::SITECALL_WIDGET ] ) ? $postMeta[ self::SITECALL_WIDGET ] : [];

		switch ( current( $widgetId ) ) {
			case self::SITECALL_TEMPLATE_WIDGET:
				$templateWidget = FocusSitecall_Templates_Sitecalls_Model::getDefaultTemplateWidget( $postMeta, $post->ID );
				$widget         = FocusSitecall_Templates_Sitecalls_Model::assignActiveGlobalWidget( $templateWidget );
				break;
			case self::SITECALL_GLOBAL_WIDGET:
				$widgetUuid   = get_option( FocusSitecall_Model::SITECALL_DEFAULT_GLOBAL_OPTION_KEY );
				$globalWidget = FocusSitecall_Sitecalls_Model::getWidgetById( $widgetUuid );
				$widget       = FocusSitecall_Templates_Sitecalls_Model::assignActiveTemplateWidget( $globalWidget, $postMeta, $post->ID );
				break;
			default:
				$widget = FocusSitecall_Sitecalls_Model::getWidgetById( current( $widgetId ) );
		}
		if ( isset( $widget['id'] ) ) {
			$widgetCode = FocusSitecall_Sitecalls_Model::getCodeById( $widget['id'] );
		}

		if ( ! empty( $widgetCode ) ) {
			echo $widgetCode;
		}
	}

	public function save_post( $post_id ) {
		$post_meta             = get_post_meta( $post_id );
		$defaultTemplateWidget = FocusSitecall_Templates_Sitecalls_Model::getDefaultTemplateWidget( $post_meta, $post_id );
		$defaultGlobalWidget   = get_option( FocusSitecall_Model::SITECALL_DEFAULT_GLOBAL_OPTION_KEY );

		if ( ! isset( $post_meta[ self::SITECALL_WIDGET ] ) ) {
			$this->assignWidgetToNewPage( $defaultGlobalWidget, $defaultTemplateWidget, $post_id );
		} else {
			update_post_meta( $post_id, self::SITECALL_WIDGET, sanitize_text_field( $_POST[ self::SITECALL_WIDGET ] ) );
		}
	}

	public function page_widget_dropdown() {
		add_meta_box(
			'widget_dropdown',
			'Focus SiteCall',
			array( $this, 'process_dropdown' ),
			'page',
			'side',
			'low',
			FocusSitecall_Sitecalls_Model::getAll()
		);
	}

	public function process_dropdown( $post, $metaData ) {
		$postMeta = get_post_meta( $post->ID );
		$widgetId = ( isset( $postMeta[ self::SITECALL_WIDGET ]) && is_array( $postMeta[ self::SITECALL_WIDGET ] ) ) ? current( $postMeta[ self::SITECALL_WIDGET ] ) : [];
		$output   = sprintf( '<select name="%s">', self::SITECALL_WIDGET );

		if ( ! empty( $metaData['args'] ) ) {
			$defaultOption = $this->getDefaultOption( $metaData['args'], $widgetId );

			if ( ! $defaultOption ) {
				$output .= '<option selected="selected">' . __('(none)', 'focus-sitecall-pro') . '</option>';
			} else {
				$output .= '<option>' . __('(none)', 'focus-sitecall-pro') . '</option>';
			}

			$defaultTemplateWidget = FocusSitecall_Templates_Sitecalls_Model::getDefaultTemplateWidget( $postMeta, $post->ID );
			if ( ! empty( $defaultTemplateWidget ) ) {
				if ( $defaultOption === self::SITECALL_TEMPLATE_WIDGET ) {
					$output .= sprintf( '<option value="%s" selected="selected">' . __('Default for template(%s)', 'focus-sitecall-pro') . '</option>', self::SITECALL_TEMPLATE_WIDGET, $defaultTemplateWidget['name'] );
				} else {
					$output .= sprintf( '<option value="%s">' . __('Default for template(%s)', 'focus-sitecall-pro') . '</option>', self::SITECALL_TEMPLATE_WIDGET, $defaultTemplateWidget['name'] );
				}
			}

			$defaultGlobalWidgetId = get_option( FocusSitecall_Model::SITECALL_DEFAULT_GLOBAL_OPTION_KEY );
			if ( isset( $defaultGlobalWidgetId ) && $defaultGlobalWidgetId !== FocusSitecall_Sitecalls_Model::NO_WIDGETS_DEFINED ) {
				$globalWidget = FocusSitecall_Templates_Sitecalls_Model::getWidgetIfExists( $defaultGlobalWidgetId );
				if ( $defaultOption === self::SITECALL_GLOBAL_WIDGET ) {
					$output .= sprintf( '<option value="%s" selected="selected">' . __('Default for theme(%s)', 'focus-sitecall-pro') . '</option>', self::SITECALL_GLOBAL_WIDGET, $globalWidget['name'] );
				} else {
					$output .= sprintf( '<option value="%s">' . __('Default for theme(%s)', 'focus-sitecall-pro') . '</option>', self::SITECALL_GLOBAL_WIDGET, $globalWidget['name'] );
				}
			}

			foreach ( $metaData['args'] as $widget ) {
				if ( $widget['id'] === $defaultOption ) {
					$output .= sprintf( '<option value="%s" selected="selected">%s</option>', $widget['id'], $widget['name'] );
				} else {
					$output .= sprintf( '<option value="%s">%s</option>', $widget['id'], $widget['name'] );
				}
			}
		} else {
			$output .= '<option selected="selected">' . __('No defined widgets', 'focus-sitecall-pro') . '</option>';
		}
		$output .= '</select>';

		echo $output;
	}

	private function getDefaultOption( $widgets, $widgetId ) {
		switch ( $widgetId ) {
			case self::SITECALL_GLOBAL_WIDGET:
				$defaultOption = self::SITECALL_GLOBAL_WIDGET;
				break;
			case self::SITECALL_TEMPLATE_WIDGET:
				$defaultOption = self::SITECALL_TEMPLATE_WIDGET;
				break;
			default:
				foreach ( $widgets as $widget ) {
					if ( $widget['id'] === $widgetId ) {
						$defaultOption = $widgetId;
					}
				}
		}

		return isset( $defaultOption ) ? $defaultOption : false;
	}

	private function assignWidgetToNewPage( $defaultGlobalWidget, $defaultTemplateWidget, $post_id ) {
		if ( isset( $post_meta['_wp_page_template'] ) || isset( $defaultTemplateWidget['id'] ) ) {
			add_post_meta( $post_id, self::SITECALL_WIDGET, self::SITECALL_TEMPLATE_WIDGET );
		} elseif ( $defaultGlobalWidget && $defaultGlobalWidget !== "0" ) {
			add_post_meta( $post_id, self::SITECALL_WIDGET, self::SITECALL_GLOBAL_WIDGET );
		} else {
			add_post_meta( $post_id, self::SITECALL_WIDGET, self::SITECALL_TEMPLATE_WIDGET );
		}
	}
}

add_action( 'wp_footer', array('FocusSitecall_Add_Widget', 'add_to_footer' ) );
